local day_length_ticks
local dusk_length_ticks
local night_length_ticks
local dawn_length_ticks
local cycle_length_ticks
local day_offset_ticks
local dusk_begin_tick
local night_begin_tick
local dawn_begin_tick
local day_begin_tick
local cycle_phase_tick
local frozen = false

local function compute_values()
    day_length_ticks = settings.global["dayphaseadjuster-daylength"].value * 60 or 208 * 60
    dusk_length_ticks = settings.global["dayphaseadjuster-dusklength"].value * 60 or 83 * 60
    night_length_ticks = settings.global["dayphaseadjuster-nightlength"].value * 60 or 208 * 60
    dawn_length_ticks = settings.global["dayphaseadjuster-dawnlength"].value * 60 or 83 * 60
    cycle_length_ticks = day_length_ticks + dusk_length_ticks + night_length_ticks + dawn_length_ticks
    day_offset_ticks = day_length_ticks / 2
    dusk_begin_tick = day_offset_ticks
    night_begin_tick = dusk_begin_tick + dusk_length_ticks
    dawn_begin_tick = night_begin_tick + night_length_ticks
    day_begin_tick = dawn_begin_tick + dawn_length_ticks
end
script.on_configuration_changed(compute_values)

local function on_init() 
    compute_values()
end
script.on_init(on_init)

local function on_load(event)
    compute_values()
end
script.on_load(on_load)


local function on_tick(event)

    if not frozen then
        game.surfaces['nauvis'].freeze_daytime(true)
        frozen = true
    end

    cycle_phase_tick = game.tick % cycle_length_ticks

    if cycle_phase_tick < dusk_begin_tick then
        -- we are in day
        game.surfaces['nauvis'].daytime = (((cycle_phase_tick + day_offset_ticks) / day_length_ticks) / 2 ) - 0.25
    elseif cycle_phase_tick < night_begin_tick then
        -- we are in dusk
        game.surfaces['nauvis'].daytime = (((cycle_phase_tick - day_offset_ticks) / dusk_length_ticks) / 5 ) + 0.25
    elseif cycle_phase_tick < dawn_begin_tick then
        -- we are in night
        game.surfaces['nauvis'].daytime = (((cycle_phase_tick - night_begin_tick) / night_length_ticks) / 10 ) + 0.45
    elseif cycle_phase_tick < day_begin_tick then
        -- we are in dawn
        game.surfaces['nauvis'].daytime = (((cycle_phase_tick - dawn_begin_tick) / dawn_length_ticks) / 5 ) + 0.55
    else
        -- we are in the part of day that's at 0.75 to 1.00
        game.surfaces['nauvis'].daytime = (((cycle_phase_tick - day_begin_tick) / day_length_ticks) / 2 ) + 0.75
    end

end
script.on_event(defines.events.on_tick, on_tick)